@@ -51,10 +51,8 @@ Q_SIGNALS:
 private Q_SLOTS:
     void onCollectionsFetched(bool success);
     void onItemsFetched(bool success, const QString &errorMessage);
-    void onModifyFinished(int changeId, const Akonadi::Item &item,
-                          Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage);
-    void onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &,
-                          Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage);
+    void onModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage);
+    void onDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorMessage);
 
     void processNextCollection();
 
@@ -76,8 +74,7 @@ private Q_SLOTS:
     void printFound(const Akonadi::Item &item, const QString &explanation = QString());
 
     void beginTest(const QString &message);
-    void endTest(bool print = true, const QString &fixExplanation = QString(),
-                 const QString &fixExplanation2 = QString());
+    void endTest(bool print = true, const QString &fixExplanation = QString(), const QString &fixExplanation2 = QString());
 
     void deleteIncidence(const Akonadi::Item &item);
 
@@ -89,15 +86,15 @@ private:
     Akonadi::IncidenceChanger *m_changer = nullptr;
     Akonadi::Collection m_currentCollection;
     Options::SanityCheck m_currentSanityCheck;
-    int m_pendingModifications;
-    int m_pendingDeletions;
-    bool m_strippingOldAlarms;
+    int m_pendingModifications = 0;
+    int m_pendingDeletions = 0;
+    bool m_strippingOldAlarms = false;
 
     QList<Akonadi::Item::Id> m_test1Results;
     QStringList m_test2Results;
 
-    int m_numDamaged;
-    bool m_fixingEnabled;
+    int m_numDamaged = 0;
+    bool m_fixingEnabled = false;
 
     QString m_summary; // to print at the end.
     QMultiMap<QString, KCalCore::Incidence::Ptr> m_incidenceMap;
